@@ -1,16 +1,18 @@
 import logging
+from typing import Callable, Dict, List, Tuple, Union, cast
+
 import numpy as np
 import tensorflow as tf
+from alibi_detect.base import (BaseDetector, FitMixin, ThresholdMixin,
+                               adversarial_correction_dict,
+                               adversarial_prediction_dict)
+from alibi_detect.models.tensorflow.autoencoder import AE
+from alibi_detect.models.tensorflow.losses import loss_adv_ae
+from alibi_detect.models.tensorflow.trainer import trainer
+from alibi_detect.utils.tensorflow.prediction import predict_batch
 from tensorflow.keras.layers import Dense, Flatten
 from tensorflow.keras.losses import kld
 from tensorflow.keras.models import Model
-from typing import Callable, Dict, List, Tuple, Union
-from alibi_detect.models.tensorflow.autoencoder import AE
-from alibi_detect.models.tensorflow.trainer import trainer
-from alibi_detect.models.tensorflow.losses import loss_adv_ae
-from alibi_detect.utils.tensorflow.prediction import predict_batch
-from alibi_detect.base import (BaseDetector, FitMixin, ThresholdMixin,
-                               adversarial_prediction_dict, adversarial_correction_dict)
 
 logger = logging.getLogger(__name__)
 
@@ -56,8 +58,8 @@ class AdversarialAE(BaseDetector, FitMixin, ThresholdMixin):
                  threshold: float = None,
                  ae: tf.keras.Model = None,
                  model: tf.keras.Model = None,
-                 encoder_net: tf.keras.Sequential = None,
-                 decoder_net: tf.keras.Sequential = None,
+                 encoder_net: tf.keras.Model = None,
+                 decoder_net: tf.keras.Model = None,
                  model_hl: List[tf.keras.Model] = None,
                  hidden_layer_kld: dict = None,
                  w_model_hl: list = None,
@@ -247,10 +249,12 @@ class AdversarialAE(BaseDetector, FitMixin, ThresholdMixin):
         # model predictions
         y = predict_batch(X, self.model, batch_size=batch_size)
         y_recon = predict_batch(X_recon, self.model, batch_size=batch_size)
+        y = cast(np.ndarray, y)  # help mypy out
+        y_recon = cast(np.ndarray, y_recon)  # help mypy out
 
         # scale predictions
         if self.temperature != 1.:
-            y = y ** (1 / self.temperature)  # type: ignore
+            y = y ** (1 / self.temperature)
             y = (y / tf.reshape(tf.reduce_sum(y, axis=-1), (-1, 1))).numpy()
 
         adv_score = kld(y, y_recon).numpy()
