@@ -1,6 +1,10 @@
 import numpy as np
 from typing import Callable, Dict, Optional, Union
-from alibi_detect.utils.frameworks import has_pytorch, has_tensorflow
+from alibi_detect.utils.frameworks import has_pytorch, has_tensorflow, has_sklearn
+
+if has_sklearn:
+    from sklearn.base import ClassifierMixin
+    from alibi_detect.cd.sklearn.classifier import ClassifierDriftSklearn
 
 if has_pytorch:
     from torch.utils.data import DataLoader
@@ -16,7 +20,7 @@ class ClassifierDrift:
     def __init__(
             self,
             x_ref: Union[np.ndarray, list],
-            model: Callable,
+            model: Union[ClassifierMixin, Callable],
             backend: str = 'tensorflow',
             p_val: float = .05,
             preprocess_x_ref: bool = True,
@@ -39,6 +43,8 @@ class ClassifierDrift:
             device: Optional[str] = None,
             dataset: Optional[Callable] = None,
             dataloader: Optional[Callable] = None,
+            use_calibration: bool = False,
+            calibration_kwargs: Optional[dict] = None,
             data_type: Optional[str] = None
     ) -> None:
         """
@@ -51,26 +57,29 @@ class ClassifierDrift:
         x_ref
             Data used as reference distribution.
         model
-            PyTorch or TensorFlow classification model used for drift detection.
+            PyTorch, TensorFlow or Sklearn classification model used for drift detection.
         backend
-            Backend used for the training loop implementation.
+            Backend used for the training loop implementation. Supported: 'tensorflow' | 'pytorch' | 'sklearn'.
         p_val
             p-value used for the significance of the test.
         preprocess_x_ref
             Whether to already preprocess and store the reference data.
         update_x_ref
-            Reference data can optionally be updated to the last n instances seen by the detector
-            or via reservoir sampling with size n. For the former, the parameter equals {'last': n} while
-            for reservoir sampling {'reservoir_sampling': n} is passed.
+            Reference data can optionally be updated to the last `n` instances seen by the detector
+            or via reservoir sampling with size `n`. For the former, the parameter equals `{'last': n}` while
+            for reservoir sampling `{'reservoir_sampling': n}` is passed.
         preprocess_fn
             Function to preprocess the data before computing the data drift metrics.
         preds_type
-            Whether the model outputs 'probs' or 'logits'
+            Whether the model outputs 'probs' (probabilities - for 'tensorflow', 'pytorch', 'sklearn' models),
+            'logits' (for 'pytorch', 'tensorflow' models), 'scores' (for 'sklearn' models if `decision_function`
+            is supported).
         binarize_preds
-            Whether to test for discrepency on soft  (e.g. probs/logits) model predictions directly
+            Whether to test for discrepancy on soft  (e.g. probs/logits/scores) model predictions directly
             with a K-S test or binarise to 0-1 prediction errors and apply a binomial test.
         reg_loss_fn
-            The regularisation term reg_loss_fn(model) is added to the loss function being optimized.
+            The regularisation term `reg_loss_fn(model)` is added to the loss function being optimized.
+            Only relevant for 'tensorflow` and 'pytorch' backends.
         train_size
             Optional fraction (float between 0 and 1) of the dataset used to train the classifier.
             The drift is detected on `1 - train_size`. Cannot be used in combination with `n_folds`.
@@ -85,38 +94,49 @@ class ClassifierDrift:
         seed
             Optional random seed for fold selection.
         optimizer
-            Optimizer used during training of the classifier.
+            Optimizer used during training of the classifier. Only relevant for 'tensorflow' and 'pytorch' backends.
         learning_rate
-            Learning rate used by optimizer.
+            Learning rate used by optimizer. Only relevant for 'tensorflow' and 'pytorch' backends.
         batch_size
-            Batch size used during training of the classifier.
+            Batch size used during training of the classifier. Only relevant for 'tensorflow' and 'pytorch' backends.
         preprocess_batch_fn
             Optional batch preprocessing function. For example to convert a list of objects to a batch which can be
-            processed by the model.
+            processed by the model. Only relevant for 'tensorflow' and 'pytorch' backends.
         epochs
-            Number of training epochs for the classifier for each (optional) fold.
+            Number of training epochs for the classifier for each (optional) fold. Only relevant for 'tensorflow'
+            and 'pytorch' backends.
         verbose
-            Verbosity level during the training of the classifier. 0 is silent, 1 a progress bar.
+            Verbosity level during the training of the classifier. 0 is silent, 1 a progress bar. Only relevant for
+            'tensorflow' and 'pytorch' backends.
         train_kwargs
-            Optional additional kwargs when fitting the classifier.
+            Optional additional kwargs when fitting the classifier. Only relevant for 'tensorflow' and
+            'pytorch' backends.
         device
             Device type used. The default None tries to use the GPU and falls back on CPU if needed.
             Can be specified by passing either 'cuda', 'gpu' or 'cpu'. Only relevant for 'pytorch' backend.
         dataset
-            Dataset object used during training.
+            Dataset object used during training. Only relevant for 'tensorflow' and 'pytorch' backends.
         dataloader
             Dataloader object used during training. Only relevant for 'pytorch' backend.
+        use_calibration
+            Whether to use calibration. Calibration can be used on top of any model.
+            Only relevant for 'sklearn' backend.
+        calibration_kwargs
+            Optional additional kwargs for calibration. Only relevant for 'sklearn' backend.
+            See https://scikit-learn.org/stable/modules/generated/sklearn.calibration.CalibratedClassifierCV.html
+            for more details.
         data_type
             Optionally specify the data type (tabular, image or time-series). Added to metadata.
         """
         super().__init__()
 
         backend = backend.lower()
-        if backend == 'tensorflow' and not has_tensorflow or backend == 'pytorch' and not has_pytorch:
+        if (backend == 'tensorflow' and not has_tensorflow) or (backend == 'pytorch' and not has_pytorch) or \
+                (backend == 'sklearn' and not has_sklearn):
             raise ImportError(f'{backend} not installed. Cannot initialize and run the '
                               f'ClassifierDrift detector with {backend} backend.')
-        elif backend not in ['tensorflow', 'pytorch']:
-            raise NotImplementedError(f'{backend} not implemented. Use tensorflow or pytorch instead.')
+        elif backend not in ['tensorflow', 'pytorch', 'sklearn']:
+            raise NotImplementedError(f"{backend} not implemented. Use 'tensorflow', 'pytorch' or 'sklearn' instead.")
 
         kwargs = locals()
         args = [kwargs['x_ref'], kwargs['model']]
@@ -125,18 +145,25 @@ class ClassifierDrift:
             pop_kwargs += ['optimizer']
         [kwargs.pop(k, None) for k in pop_kwargs]
 
-        if backend == 'tensorflow' and has_tensorflow:
-            pop_kwargs = ['device', 'dataloader']
+        if backend == 'tensorflow':
+            pop_kwargs = ['device', 'dataloader', 'use_calibration', 'calibration_kwargs']
             [kwargs.pop(k, None) for k in pop_kwargs]
             if dataset is None:
                 kwargs.update({'dataset': TFDataset})
             self._detector = ClassifierDriftTF(*args, **kwargs)  # type: ignore
-        else:
+        elif backend == 'pytorch':
+            pop_kwargs = ['use_calibration', 'calibration_kwargs']
+            [kwargs.pop(k, None) for k in pop_kwargs]
             if dataset is None:
                 kwargs.update({'dataset': TorchDataset})
             if dataloader is None:
                 kwargs.update({'dataloader': DataLoader})
             self._detector = ClassifierDriftTorch(*args, **kwargs)  # type: ignore
+        else:
+            pop_kwargs = ['reg_loss_fn', 'optimizer', 'learning_rate', 'batch_size', 'preprocess_batch_fn',
+                          'epochs', 'train_kwargs', 'device',  'dataset', 'dataloader', 'verbose']
+            [kwargs.pop(k, None) for k in pop_kwargs]
+            self._detector = ClassifierDriftSklearn(*args, **kwargs)  # type: ignore
         self.meta = self._detector.meta
 
     def predict(self, x: Union[np.ndarray, list],  return_p_val: bool = True,
@@ -162,10 +189,12 @@ class ClassifierDrift:
 
         Returns
         -------
-        Dictionary containing 'meta' and 'data' dictionaries.
-        'meta' has the model's metadata.
-        'data' contains the drift prediction and optionally the p-value, performance of the classifier
-        relative to its expectation under the no-change null, the out-of-fold classifier model
-        prediction probabilities on the reference and test data, and the trained model.
+        Dictionary containing 'meta' and 'data' dictionaries
+
+         - 'meta' - has the model's metadata.
+
+         - 'data' - contains the drift prediction and optionally the p-value, performance of the classifier \
+        relative to its expectation under the no-change null, the out-of-fold classifier model \
+        prediction probabilities on the reference and test data, and the trained model. \
         """
         return self._detector.predict(x, return_p_val, return_distance, return_probs, return_model)
