@@ -1,5 +1,5 @@
 import numpy as np
-from typing import Callable, Dict, Optional, Union
+from typing import Any, Callable, Dict, Optional, Union
 from alibi_detect.utils.frameworks import has_pytorch, has_tensorflow
 
 if has_pytorch:
@@ -33,7 +33,8 @@ class MMDDriftOnline:
         x_ref
             Data used as reference distribution.
         ert
-            The expected run-time (ERT) in the absence of drift.
+            The expected run-time (ERT) in the absence of drift. For the multivariate detectors, the ERT is defined
+            as the expected run-time from t=0.
         window_size
             The size of the sliding test-window used to compute the test-statistic.
             Smaller windows focus on responding quickly to severe drift, larger windows focus on
@@ -106,7 +107,7 @@ class MMDDriftOnline:
         "Resets the detector but does not reconfigure thresholds."
         self._detector.reset()
 
-    def predict(self, x_t: Union[np.ndarray, list], return_test_stat: bool = True) \
+    def predict(self, x_t: Union[np.ndarray, Any], return_test_stat: bool = True) \
             -> Dict[Dict[str, str], Dict[str, Union[int, float]]]:
         """
         Predict whether the most recent window of data has drifted from the reference data.
@@ -125,3 +126,18 @@ class MMDDriftOnline:
         'data' contains the drift prediction and optionally the test-statistic and threshold.
         """
         return self._detector.predict(x_t, return_test_stat)
+
+    def score(self, x_t: Union[np.ndarray, Any]) -> float:
+        """
+        Compute the test-statistic (squared MMD) between the reference window and test window.
+
+        Parameters
+        ----------
+        x_t
+            A single instance to be added to the test-window.
+
+        Returns
+        -------
+        Squared MMD estimate between reference window and test window.
+        """
+        return self._detector.score(x_t)
