@@ -1,12 +1,12 @@
 from tqdm import tqdm
 import numpy as np
 import tensorflow as tf
-from typing import Callable, Optional, Union
-from alibi_detect.cd.base_online import BaseDriftOnline
+from typing import Any, Callable, Optional, Union
+from alibi_detect.cd.base_online import BaseMultiDriftOnline
 from alibi_detect.utils.tensorflow import GaussianRBF, quantile, permed_lsdds
 
 
-class LSDDDriftOnlineTF(BaseDriftOnline):
+class LSDDDriftOnlineTF(BaseMultiDriftOnline):
     def __init__(
             self,
             x_ref: Union[np.ndarray, list],
@@ -31,7 +31,8 @@ class LSDDDriftOnlineTF(BaseDriftOnline):
         x_ref
             Data used as reference distribution.
         ert
-            The expected run-time (ERT) in the absence of drift.
+            The expected run-time (ERT) in the absence of drift. For the multivariate detectors, the ERT is defined
+            as the expected run-time from t=0.
         window_size
             The size of the sliding test-window used to compute the test-statistic.
             Smaller windows focus on responding quickly to severe drift, larger windows focus on
@@ -164,27 +165,29 @@ class LSDDDriftOnlineTF(BaseDriftOnline):
             h_init = self.c2s - tf.reduce_mean(self.k_xtc, axis=0)  # (Eqn 21)
             lsdd_init = h_init[None, :] @ self.H_lam_inv @ h_init[:, None]  # (Eqn 11)
 
-    def score(self, x_t: np.ndarray) -> Union[float, None]:
+    def _update_state(self, x_t: tf.Tensor):
+        self.t += 1
+        k_xtc = self.kernel(x_t, self.kernel_centers)
+        self.test_window = tf.concat([self.test_window[(1-self.window_size):], x_t], axis=0)
+        self.k_xtc = tf.concat([self.k_xtc[(1-self.window_size):], k_xtc], axis=0)
+
+    def score(self, x_t: Union[np.ndarray, Any]) -> float:
         """
         Compute the test-statistic (LSDD) between the reference window and test window.
 
         Parameters
         ----------
         x_t
-            A single instance.
+            A single instance to be added to the test-window.
 
         Returns
         -------
         LSDD estimate between reference window and test window.
-        If the test-window is not yet full then a test-statistic of None is returned.
         """
-        x_t = tf.convert_to_tensor(x_t[None, :])
+        x_t = super()._preprocess_xt(x_t)
+        x_t = tf.convert_to_tensor(x_t)
         x_t = self._normalize(x_t)
-        k_xtc = self.kernel(x_t, self.kernel_centers)
-
-        self.test_window = tf.concat([self.test_window[(1-self.window_size):], x_t], axis=0)
-        self.k_xtc = tf.concat([self.k_xtc[(1-self.window_size):], k_xtc], axis=0)
+        self._update_state(x_t)
         h = self.c2s - tf.reduce_mean(self.k_xtc, axis=0)  # (Eqn 21)
         lsdd = h[None, :] @ self.H_lam_inv @ h[:, None]  # (Eqn 11)
-
         return float(lsdd)
