@@ -4,9 +4,10 @@ from .mahalanobis import Mahalanobis
 from .ae import OutlierAE
 from .vae import OutlierVAE
 from .vaegmm import OutlierVAEGMM
-from .prophet import OutlierProphet
+from .prophet import PROPHET_INSTALLED, OutlierProphet
 from .seq2seq import OutlierSeq2Seq
 from .sr import SpectralResidual
+from .llr import LLR
 
 __all__ = [
     "OutlierAEGMM",
@@ -15,7 +16,10 @@ __all__ = [
     "OutlierAE",
     "OutlierVAE",
     "OutlierVAEGMM",
-    "OutlierProphet",
     "OutlierSeq2Seq",
-    "SpectralResidual"
+    "SpectralResidual",
+    "LLR"
 ]
+
+if PROPHET_INSTALLED:
+    __all__ += ["OutlierProphet"]
