@@ -1,10 +1,11 @@
 import logging
 import os
+from urllib.parse import urljoin, quote_plus
 from pathlib import Path
 import dill
 import tensorflow as tf
 from tensorflow.python.keras import backend
-from typing import Tuple, Union
+from typing import Tuple, Union, List
 from io import BytesIO
 import requests
 from requests import RequestException
@@ -36,6 +37,9 @@ Data = Union[
     SpectralResidual
 ]
 
+"""Number of seconds to wait for URL requests before raising an error."""
+TIMEOUT = 10
+
 
 def get_pixelcnn_default_kwargs():
     dist = PixelCNN(
@@ -73,7 +77,7 @@ def fetch_tf_model(dataset: str, model: str) -> tf.keras.Model:
     Pretrained tensorflow model.
     """
     url = 'https://storage.googleapis.com/seldon-models/alibi-detect/classifier/'
-    path_model = os.path.join(url, dataset, model, 'model.h5')
+    path_model = _join_url(url, [dataset, model, 'model.h5'])
     save_path = tf.keras.utils.get_file(Path(model + '.h5').resolve(), path_model)
     if dataset == 'cifar10' and model == 'resnet56':
         custom_objects = {'backend': backend}
@@ -94,18 +98,18 @@ def fetch_enc_dec(url: str, filepath: Union[str, os.PathLike]) -> None:
     filepath
         Local directory to save detector to.
     """
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     if not model_path.is_dir():
         model_path.mkdir(parents=True, exist_ok=True)
     # encoder and decoder
     tf.keras.utils.get_file(
         model_path.joinpath('encoder_net.h5'),
-        os.path.join(url_models, 'encoder_net.h5')
+        _join_url(url_models, 'encoder_net.h5')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('decoder_net.h5'),
-        os.path.join(url_models, 'decoder_net.h5')
+        _join_url(url_models, 'decoder_net.h5')
     )
 
 
@@ -121,20 +125,20 @@ def fetch_ae(url: str, filepath: Union[str, os.PathLike]) -> None:
         Local directory to save detector to.
     """
     fetch_enc_dec(url, filepath)
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     # encoder and decoder
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('ae.ckpt.index'),
-        os.path.join(url_models, 'ae.ckpt.index')
+        _join_url(url_models, 'ae.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('ae.ckpt.data-00000-of-00001'),
-        os.path.join(url_models, 'ae.ckpt.data-00000-of-00001')
+        _join_url(url_models, 'ae.ckpt.data-00000-of-00001')
     )
 
 
@@ -152,27 +156,27 @@ def fetch_ad_ae(url: str, filepath: Union[str, os.PathLike], state_dict: dict) -
         Dictionary containing the detector's parameters.
     """
     fetch_enc_dec(url, filepath)
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     tf.keras.utils.get_file(
         model_path.joinpath('model.h5'),
-        os.path.join(url_models, 'model.h5')
+        _join_url(url_models, 'model.h5')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('ae.ckpt.index'),
-        os.path.join(url_models, 'ae.ckpt.index')
+        _join_url(url_models, 'ae.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('ae.ckpt.data-00000-of-00002'),
-        os.path.join(url_models, 'ae.ckpt.data-00000-of-00002')
+        _join_url(url_models, 'ae.ckpt.data-00000-of-00002')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('ae.ckpt.data-00001-of-00002'),
-        os.path.join(url_models, 'ae.ckpt.data-00001-of-00002')
+        _join_url(url_models, 'ae.ckpt.data-00001-of-00002')
     )
     hidden_layer_kld = state_dict['hidden_layer_kld']
     if hidden_layer_kld:
@@ -180,15 +184,15 @@ def fetch_ad_ae(url: str, filepath: Union[str, os.PathLike], state_dict: dict) -
             hl = 'model_hl_' + str(i)
             tf.keras.utils.get_file(
                 model_path.joinpath(hl + '.ckpt.index'),
-                os.path.join(url_models, hl + '.ckpt.index')
+                _join_url(url_models, hl + '.ckpt.index')
             )
             tf.keras.utils.get_file(
                 model_path.joinpath(hl + '.ckpt.data-00000-of-00002'),
-                os.path.join(url_models, hl + '.ckpt.data-00000-of-00002')
+                _join_url(url_models, hl + '.ckpt.data-00000-of-00002')
             )
             tf.keras.utils.get_file(
                 model_path.joinpath(hl + '.ckpt.data-00001-of-00002'),
-                os.path.join(url_models, hl + '.ckpt.data-00001-of-00002')
+                _join_url(url_models, hl + '.ckpt.data-00001-of-00002')
             )
 
 
@@ -203,18 +207,18 @@ def fetch_ad_md(url: str, filepath: Union[str, os.PathLike]) -> None:
     filepath
         Local directory to save detector to.
     """
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     if not model_path.is_dir():
         model_path.mkdir(parents=True, exist_ok=True)
     # encoder and decoder
     tf.keras.utils.get_file(
         model_path.joinpath('model.h5'),
-        os.path.join(url_models, 'model.h5')
+        _join_url(url_models, 'model.h5')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('distilled_model.h5'),
-        os.path.join(url_models, 'distilled_model.h5')
+        _join_url(url_models, 'distilled_model.h5')
     )
 
 
@@ -232,23 +236,23 @@ def fetch_aegmm(url: str, filepath: Union[str, os.PathLike]) -> None:
     # save encoder and decoder
     fetch_enc_dec(url, filepath)
     # save GMM network
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     tf.keras.utils.get_file(
         model_path.joinpath('gmm_density_net.h5'),
-        os.path.join(url_models, 'gmm_density_net.h5')
+        _join_url(url_models, 'gmm_density_net.h5')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('aegmm.ckpt.index'),
-        os.path.join(url_models, 'aegmm.ckpt.index')
+        _join_url(url_models, 'aegmm.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('aegmm.ckpt.data-00000-of-00001'),
-        os.path.join(url_models, 'aegmm.ckpt.data-00000-of-00001')
+        _join_url(url_models, 'aegmm.ckpt.data-00000-of-00001')
     )
 
 
@@ -265,19 +269,19 @@ def fetch_vae(url: str, filepath: Union[str, os.PathLike]) -> None:
     """
     fetch_enc_dec(url, filepath)
     # save VAE weights
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('vae.ckpt.index'),
-        os.path.join(url_models, 'vae.ckpt.index')
+        _join_url(url_models, 'vae.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('vae.ckpt.data-00000-of-00001'),
-        os.path.join(url_models, 'vae.ckpt.data-00000-of-00001')
+        _join_url(url_models, 'vae.ckpt.data-00000-of-00001')
     )
 
 
@@ -295,23 +299,23 @@ def fetch_vaegmm(url: str, filepath: Union[str, os.PathLike]) -> None:
     # save encoder and decoder
     fetch_enc_dec(url, filepath)
     # save GMM network
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     tf.keras.utils.get_file(
         model_path.joinpath('gmm_density_net.h5'),
-        os.path.join(url_models, 'gmm_density_net.h5')
+        _join_url(url_models, 'gmm_density_net.h5')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('vaegmm.ckpt.index'),
-        os.path.join(url_models, 'vaegmm.ckpt.index')
+        _join_url(url_models, 'vaegmm.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('vaegmm.ckpt.data-00000-of-00001'),
-        os.path.join(url_models, 'vaegmm.ckpt.data-00000-of-00001')
+        _join_url(url_models, 'vaegmm.ckpt.data-00000-of-00001')
     )
 
 
@@ -326,27 +330,27 @@ def fetch_seq2seq(url: str, filepath: Union[str, os.PathLike]) -> None:
     filepath
         Local directory to save detector to.
     """
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     if not model_path.is_dir():
         model_path.mkdir(parents=True, exist_ok=True)
     # save seq2seq
     tf.keras.utils.get_file(
         model_path.joinpath('checkpoint'),
-        os.path.join(url_models, 'checkpoint')
+        _join_url(url_models, 'checkpoint')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('seq2seq.ckpt.index'),
-        os.path.join(url_models, 'seq2seq.ckpt.index')
+        _join_url(url_models, 'seq2seq.ckpt.index')
     )
     tf.keras.utils.get_file(
         model_path.joinpath('seq2seq.ckpt.data-00000-of-00001'),
-        os.path.join(url_models, 'seq2seq.ckpt.data-00000-of-00001')
+        _join_url(url_models, 'seq2seq.ckpt.data-00000-of-00001')
     )
     # save threshold network
     tf.keras.utils.get_file(
         model_path.joinpath('threshold_net.h5'),
-        os.path.join(url_models, 'threshold_net.h5')
+        _join_url(url_models, 'threshold_net.h5')
     )
 
 
@@ -361,29 +365,29 @@ def fetch_llr(url: str, filepath: Union[str, os.PathLike]) -> str:
     filepath
         Local directory to save detector to.
     """
-    url_models = os.path.join(url, 'model')
+    url_models = _join_url(url, 'model')
     model_path = Path(filepath).joinpath('model').resolve()
     if not model_path.is_dir():
         model_path.mkdir(parents=True, exist_ok=True)
     try:
         tf.keras.utils.get_file(
             model_path.joinpath('model_s.h5'),
-            os.path.join(url_models, 'model_s.h5')
+            _join_url(url_models, 'model_s.h5')
         )
         tf.keras.utils.get_file(
             model_path.joinpath('model_b.h5'),
-            os.path.join(url_models, 'model_b.h5')
+            _join_url(url_models, 'model_b.h5')
         )
         model_type = 'weights'
         return model_type
     except Exception:
         tf.keras.utils.get_file(
             model_path.joinpath('model.h5'),
-            os.path.join(url_models, 'model.h5')
+            _join_url(url_models, 'model.h5')
         )
         tf.keras.utils.get_file(
             model_path.joinpath('model_background.h5'),
-            os.path.join(url_models, 'model_background.h5')
+            _join_url(url_models, 'model_background.h5')
         )
         return 'model'
 
@@ -408,14 +412,14 @@ def fetch_state_dict(url: str, filepath: Union[str, os.PathLike],
     """
     # Check if metadata stored as dill or pickle
     try:
-        url_meta = os.path.join(url, 'meta.dill')
-        resp = requests.get(url_meta, timeout=2)
+        url_meta = _join_url(url, 'meta.dill')
+        resp = requests.get(url_meta, timeout=TIMEOUT)
         resp.raise_for_status()
         suffix = '.dill'
     except RequestException:
         try:
-            url_meta = os.path.join(url, 'meta.pickle')
-            resp = requests.get(url_meta, timeout=2)
+            url_meta = _join_url(url, 'meta.pickle')
+            resp = requests.get(url_meta, timeout=TIMEOUT)
             resp.raise_for_status()
             suffix = '.pickle'
         except RequestException:
@@ -425,7 +429,7 @@ def fetch_state_dict(url: str, filepath: Union[str, os.PathLike],
     # Load metadata and state_dict
     meta = dill.load(BytesIO(resp.content))
     try:
-        url_state = os.path.join(url, meta['name'] + suffix)
+        url_state = _join_url(url, meta['name'] + suffix)
         resp = requests.get(url_state)
         resp.raise_for_status()
     except RequestException:
@@ -477,9 +481,9 @@ def fetch_detector(filepath: Union[str, os.PathLike],
     # create url of detector
     url = 'https://storage.googleapis.com/seldon-models/alibi-detect/'
     if detector_type == 'adversarial':
-        url = os.path.join(url, 'ad', dataset, model, detector_name)
+        url = _join_url(url, ['ad', dataset, model, detector_name])
     elif detector_type == 'outlier':
-        url = os.path.join(url, 'od', detector_name, dataset)
+        url = _join_url(url, ['od', detector_name, dataset])
 
     # fetch the metadata and state dict
     meta, state_dict = fetch_state_dict(url, filepath, save_state_dict=True)
@@ -511,3 +515,26 @@ def fetch_detector(filepath: Union[str, os.PathLike],
             kwargs = get_pixelcnn_default_kwargs()
     detector = load_detector(filepath, **kwargs)
     return detector
+
+
+def _join_url(base: str, parts: Union[str, List[str]]) -> str:
+    """
+    Constructs a full (“absolute”) URL by combining a “base URL” (base) with additional relative URL parts.
+    The behaviour is similar to os.path.join() on linux, but also behaves consistently on Windows.
+
+    Parameters
+    ----------
+    base
+        The base URL, e.g. `'https://mysite.com/'`.
+    parts
+        Part to append, or list of parts to append e.g. `['/dir1/', 'dir2', 'dir3']`.
+
+    Returns
+    -------
+    The joined url e.g. `https://mysite.com/dir1/dir2/dir3`.
+    """
+    parts = [parts] if isinstance(parts, str) else parts
+    if len(parts) == 0:
+        raise TypeError("The `parts` argument must contain at least one item.")
+    url = urljoin(base + "/", "/".join(quote_plus(part.strip(r"\/"), safe="/") for part in parts))
+    return url
