@@ -1,13 +1,16 @@
-from .distance import mmd2, mmd2_from_kernel_matrix, squared_pairwise_distance, permed_lsdds
-from .kernels import GaussianRBF
+from .distance import mmd2, mmd2_from_kernel_matrix, squared_pairwise_distance
+from .distance import permed_lsdds, batch_compute_kernel_matrix
+from .kernels import GaussianRBF, DeepKernel
 from .prediction import predict_batch, predict_batch_transformer
 from .misc import zero_diag, quantile
 
 __all__ = [
+    "batch_compute_kernel_matrix",
     "mmd2",
     "mmd2_from_kernel_matrix",
     "squared_pairwise_distance",
     "GaussianRBF",
+    "DeepKernel",
     "permed_lsdds",
     "predict_batch",
     "predict_batch_transformer",
